from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Media.Playlists
import win32more.Windows.Storage
import win32more.Windows.Win32.System.WinRT
class IPlaylist(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Playlists.IPlaylist'
    _iid_ = Guid('{803736f5-cf44-4d97-83b3-7a089e9ab663}')
    @winrt_commethod(6)
    def get_Files(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Storage.StorageFile]: ...
    @winrt_commethod(7)
    def SaveAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def SaveAsAsync(self, saveLocation: win32more.Windows.Storage.IStorageFolder, desiredName: WinRT_String, option: win32more.Windows.Storage.NameCollisionOption) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_commethod(9)
    def SaveAsWithFormatAsync(self, saveLocation: win32more.Windows.Storage.IStorageFolder, desiredName: WinRT_String, option: win32more.Windows.Storage.NameCollisionOption, playlistFormat: win32more.Windows.Media.Playlists.PlaylistFormat) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    Files = property(get_Files, None)
class IPlaylistStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Playlists.IPlaylistStatics'
    _iid_ = Guid('{c5c331cd-81f9-4ff3-95b9-70b6ff046b68}')
    @winrt_commethod(6)
    def LoadAsync(self, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Playlists.Playlist]: ...
class Playlist(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Playlists.IPlaylist
    _classid_ = 'Windows.Media.Playlists.Playlist'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Media.Playlists.Playlist.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Media.Playlists.Playlist: ...
    @winrt_mixinmethod
    def get_Files(self: win32more.Windows.Media.Playlists.IPlaylist) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def SaveAsync(self: win32more.Windows.Media.Playlists.IPlaylist) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def SaveAsAsync(self: win32more.Windows.Media.Playlists.IPlaylist, saveLocation: win32more.Windows.Storage.IStorageFolder, desiredName: WinRT_String, option: win32more.Windows.Storage.NameCollisionOption) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def SaveAsWithFormatAsync(self: win32more.Windows.Media.Playlists.IPlaylist, saveLocation: win32more.Windows.Storage.IStorageFolder, desiredName: WinRT_String, option: win32more.Windows.Storage.NameCollisionOption, playlistFormat: win32more.Windows.Media.Playlists.PlaylistFormat) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_classmethod
    def LoadAsync(cls: win32more.Windows.Media.Playlists.IPlaylistStatics, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Playlists.Playlist]: ...
    Files = property(get_Files, None)
class PlaylistFormat(Enum, Int32):
    WindowsMedia = 0
    Zune = 1
    M3u = 2
PlaylistsContract: UInt32 = 65536


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security.Authentication.Identity.Provider
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
import win32more.Windows.Win32.System.Variant
import win32more.Windows.Win32.UI.Shell.PropertiesSystem
ACCOUNT_STATE = Int32
NOT_CONNECTED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.ACCOUNT_STATE = 0
CONNECTING: win32more.Windows.Win32.Security.Authentication.Identity.Provider.ACCOUNT_STATE = 1
CONNECT_COMPLETED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.ACCOUNT_STATE = 2
IDENTITY_KEYWORD_ASSOCIATED: String = 'associated'
IDENTITY_KEYWORD_LOCAL: String = 'local'
IDENTITY_KEYWORD_HOMEGROUP: String = 'homegroup'
IDENTITY_KEYWORD_CONNECTED: String = 'connected'
OID_OAssociatedIdentityProviderObject: Guid = Guid('{98c5a3dd-db68-4f1a-8d2b-9079cdfeaf61}')
STR_OUT_OF_BOX_EXPERIENCE: String = 'OutOfBoxExperience'
STR_MODERN_SETTINGS_ADD_USER: String = 'ModernSettingsAddUser'
STR_OUT_OF_BOX_UPGRADE_EXPERIENCE: String = 'OutOfBoxUpgradeExperience'
STR_COMPLETE_ACCOUNT: String = 'CompleteAccount'
STR_NTH_USER_FIRST_AUTH: String = 'NthUserFirstAuth'
STR_USER_NAME: String = 'Username'
STR_PROPERTY_STORE: String = 'PropertyStore'
class AsyncIAssociatedIdentityProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2834d6ed-297e-4e72-8a51-961e86f05152}')
    @commethod(3)
    def Begin_AssociateIdentity(self, hwndParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_AssociateIdentity(self, ppPropertyStore: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Begin_DisassociateIdentity(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Finish_DisassociateIdentity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Begin_ChangeCredential(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Finish_ChangeCredential(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIConnectedIdentityProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9ce55141-bce9-4e15-824d-43d79f512f93}')
    @commethod(3)
    def Begin_ConnectIdentity(self, AuthBuffer: POINTER(Byte), AuthBufferSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_ConnectIdentity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Begin_DisconnectIdentity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Finish_DisconnectIdentity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Begin_IsConnected(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Finish_IsConnected(self, Connected: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Begin_GetUrl(self, Identifier: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL, Context: win32more.Windows.Win32.System.Com.IBindCtx) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Finish_GetUrl(self, PostData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Url: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Begin_GetAccountState(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Finish_GetAccountState(self, pState: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.Provider.ACCOUNT_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIIdentityAdvise(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3ab4c8da-d038-4830-8dd9-3253c55a127f}')
    @commethod(3)
    def Begin_IdentityUpdated(self, dwIdentityUpdateEvents: UInt32, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_IdentityUpdated(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIIdentityAuthentication(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f9a2f918-feca-4e9c-9633-61cbf13ed34d}')
    @commethod(3)
    def Begin_SetIdentityCredential(self, CredBuffer: POINTER(Byte), CredBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_SetIdentityCredential(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Begin_ValidateIdentityCredential(self, CredBuffer: POINTER(Byte), CredBufferLength: UInt32, ppIdentityProperties: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Finish_ValidateIdentityCredential(self, ppIdentityProperties: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIIdentityProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c6fc9901-c433-4646-8f48-4e4687aae2a0}')
    @commethod(3)
    def Begin_GetIdentityEnum(self, eIdentityType: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_TYPE, pFilterkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pFilterPropVarValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_GetIdentityEnum(self, ppIdentityEnum: POINTER(win32more.Windows.Win32.System.Com.IEnumUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Begin_Create(self, lpszUserName: win32more.Windows.Win32.Foundation.PWSTR, pKeywordsToAdd: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Finish_Create(self, ppPropertyStore: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Begin_Import(self, pPropertyStore: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Finish_Import(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Begin_Delete(self, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR, pKeywordsToDelete: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Finish_Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Begin_FindByUniqueID(self, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Finish_FindByUniqueID(self, ppPropertyStore: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Begin_GetProviderPropertyStore(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Finish_GetProviderPropertyStore(self, ppPropertyStore: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Begin_Advise(self, pIdentityAdvise: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IIdentityAdvise, dwIdentityUpdateEvents: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Finish_Advise(self, pdwCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Begin_UnAdvise(self, dwCookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def Finish_UnAdvise(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIIdentityStore(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{eefa1616-48de-4872-aa64-6e6206535a51}')
    @commethod(3)
    def Begin_GetCount(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_GetCount(self, pdwProviders: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Begin_GetAt(self, dwProvider: UInt32, pProvGuid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Finish_GetAt(self, pProvGuid: POINTER(Guid), ppIdentityProvider: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Begin_AddToCache(self, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR, ProviderGUID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Finish_AddToCache(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Begin_ConvertToSid(self, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR, ProviderGUID: POINTER(Guid), cbSid: UInt16, pSid: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Finish_ConvertToSid(self, pSid: POINTER(Byte), pcbRequiredSid: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Begin_EnumerateIdentities(self, eIdentityType: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_TYPE, pFilterkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pFilterPropVarValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Finish_EnumerateIdentities(self, ppIdentityEnum: POINTER(win32more.Windows.Win32.System.Com.IEnumUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Begin_Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Finish_Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIIdentityStoreEx(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fca3af9a-8a07-4eae-8632-ec3de658a36a}')
    @commethod(3)
    def Begin_CreateConnectedIdentity(self, LocalName: win32more.Windows.Win32.Foundation.PWSTR, ConnectedName: win32more.Windows.Win32.Foundation.PWSTR, ProviderGUID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_CreateConnectedIdentity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Begin_DeleteConnectedIdentity(self, ConnectedName: win32more.Windows.Win32.Foundation.PWSTR, ProviderGUID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Finish_DeleteConnectedIdentity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
CIdentityProfileHandler = Guid('{ecf5bf46-e3b6-449a-b56b-43f58f867814}')
CoClassIdentityStore = Guid('{30d49246-d217-465f-b00b-ac9ddd652eb7}')
class IAssociatedIdentityProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2af066b3-4cbb-4cba-a798-204b6af68cc0}')
    @commethod(3)
    def AssociateIdentity(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, ppPropertyStore: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DisassociateIdentity(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ChangeCredential(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IConnectedIdentityProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b7417b54-e08c-429b-96c8-678d1369ecb1}')
    @commethod(3)
    def ConnectIdentity(self, AuthBuffer: POINTER(Byte), AuthBufferSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DisconnectIdentity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsConnected(self, Connected: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetUrl(self, Identifier: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL, Context: win32more.Windows.Win32.System.Com.IBindCtx, PostData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Url: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetAccountState(self, pState: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.Provider.ACCOUNT_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDENTITY_TYPE = Int32
IDENTITIES_ALL: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_TYPE = 0
IDENTITIES_ME_ONLY: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_TYPE = 1
IDENTITY_URL = Int32
IDENTITY_URL_CREATE_ACCOUNT_WIZARD: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL = 0
IDENTITY_URL_SIGN_IN_WIZARD: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL = 1
IDENTITY_URL_CHANGE_PASSWORD_WIZARD: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL = 2
IDENTITY_URL_IFEXISTS_WIZARD: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL = 3
IDENTITY_URL_ACCOUNT_SETTINGS: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL = 4
IDENTITY_URL_RESTORE_WIZARD: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL = 5
IDENTITY_URL_CONNECT_WIZARD: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_URL = 6
class IIdentityAdvise(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4e982fed-d14b-440c-b8d6-bb386453d386}')
    @commethod(3)
    def IdentityUpdated(self, dwIdentityUpdateEvents: UInt32, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IIdentityAuthentication(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5e7ef254-979f-43b5-b74e-06e4eb7df0f9}')
    @commethod(3)
    def SetIdentityCredential(self, CredBuffer: POINTER(Byte), CredBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ValidateIdentityCredential(self, CredBuffer: POINTER(Byte), CredBufferLength: UInt32, ppIdentityProperties: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IIdentityProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0d1b9e0c-e8ba-4f55-a81b-bce934b948f5}')
    @commethod(3)
    def GetIdentityEnum(self, eIdentityType: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_TYPE, pFilterkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pFilterPropVarValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), ppIdentityEnum: POINTER(win32more.Windows.Win32.System.Com.IEnumUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Create(self, lpszUserName: win32more.Windows.Win32.Foundation.PWSTR, ppPropertyStore: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore), pKeywordsToAdd: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Import(self, pPropertyStore: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Delete(self, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR, pKeywordsToDelete: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindByUniqueID(self, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR, ppPropertyStore: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetProviderPropertyStore(self, ppPropertyStore: POINTER(win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Advise(self, pIdentityAdvise: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IIdentityAdvise, dwIdentityUpdateEvents: UInt32, pdwCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def UnAdvise(self, dwCookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IIdentityStore(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{df586fa5-6f35-44f1-b209-b38e169772eb}')
    @commethod(3)
    def GetCount(self, pdwProviders: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAt(self, dwProvider: UInt32, pProvGuid: POINTER(Guid), ppIdentityProvider: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddToCache(self, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR, ProviderGUID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ConvertToSid(self, lpszUniqueID: win32more.Windows.Win32.Foundation.PWSTR, ProviderGUID: POINTER(Guid), cbSid: UInt16, pSid: POINTER(Byte), pcbRequiredSid: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def EnumerateIdentities(self, eIdentityType: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IDENTITY_TYPE, pFilterkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pFilterPropVarValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), ppIdentityEnum: POINTER(win32more.Windows.Win32.System.Com.IEnumUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IIdentityStoreEx(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f9f9eb98-8f7f-4e38-9577-6980114ce32b}')
    @commethod(3)
    def CreateConnectedIdentity(self, LocalName: win32more.Windows.Win32.Foundation.PWSTR, ConnectedName: win32more.Windows.Win32.Foundation.PWSTR, ProviderGUID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DeleteConnectedIdentity(self, ConnectedName: win32more.Windows.Win32.Foundation.PWSTR, ProviderGUID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IdentityUpdateEvent = Int32
IDENTITY_ASSOCIATED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IdentityUpdateEvent = 1
IDENTITY_DISASSOCIATED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IdentityUpdateEvent = 2
IDENTITY_CREATED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IdentityUpdateEvent = 4
IDENTITY_IMPORTED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IdentityUpdateEvent = 8
IDENTITY_DELETED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IdentityUpdateEvent = 16
IDENTITY_PROPCHANGED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IdentityUpdateEvent = 32
IDENTITY_CONNECTED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IdentityUpdateEvent = 64
IDENTITY_DISCONNECTED: win32more.Windows.Win32.Security.Authentication.Identity.Provider.IdentityUpdateEvent = 128


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Networking.Sockets
import win32more.Windows.Security.Credentials
import win32more.Windows.Security.Cryptography.Certificates
import win32more.Windows.System
import win32more.Windows.Web.Http
import win32more.Windows.Web.Http.Filters
import win32more.Windows.Win32.System.WinRT
class HttpBaseProtocolFilter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter
    _classid_ = 'Windows.Web.Http.Filters.HttpBaseProtocolFilter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Web.Http.Filters.HttpBaseProtocolFilter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Web.Http.Filters.HttpBaseProtocolFilter: ...
    @winrt_mixinmethod
    def get_AllowAutoRedirect(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> Boolean: ...
    @winrt_mixinmethod
    def put_AllowAutoRedirect(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AllowUI(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> Boolean: ...
    @winrt_mixinmethod
    def put_AllowUI(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AutomaticDecompression(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutomaticDecompression(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CacheControl(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> win32more.Windows.Web.Http.Filters.HttpCacheControl: ...
    @winrt_mixinmethod
    def get_CookieManager(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> win32more.Windows.Web.Http.HttpCookieManager: ...
    @winrt_mixinmethod
    def get_ClientCertificate(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> win32more.Windows.Security.Cryptography.Certificates.Certificate: ...
    @winrt_mixinmethod
    def put_ClientCertificate(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter, value: win32more.Windows.Security.Cryptography.Certificates.Certificate) -> Void: ...
    @winrt_mixinmethod
    def get_IgnorableServerCertificateErrors(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Security.Cryptography.Certificates.ChainValidationResult]: ...
    @winrt_mixinmethod
    def get_MaxConnectionsPerServer(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> UInt32: ...
    @winrt_mixinmethod
    def put_MaxConnectionsPerServer(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_ProxyCredential(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_mixinmethod
    def put_ProxyCredential(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    @winrt_mixinmethod
    def get_ServerCredential(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_mixinmethod
    def put_ServerCredential(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    @winrt_mixinmethod
    def get_UseProxy(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter) -> Boolean: ...
    @winrt_mixinmethod
    def put_UseProxy(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxVersion(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter2) -> win32more.Windows.Web.Http.HttpVersion: ...
    @winrt_mixinmethod
    def put_MaxVersion(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter2, value: win32more.Windows.Web.Http.HttpVersion) -> Void: ...
    @winrt_mixinmethod
    def get_CookieUsageBehavior(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter3) -> win32more.Windows.Web.Http.Filters.HttpCookieUsageBehavior: ...
    @winrt_mixinmethod
    def put_CookieUsageBehavior(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter3, value: win32more.Windows.Web.Http.Filters.HttpCookieUsageBehavior) -> Void: ...
    @winrt_mixinmethod
    def add_ServerCustomValidationRequested(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.Http.Filters.HttpBaseProtocolFilter, win32more.Windows.Web.Http.Filters.HttpServerCustomValidationRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ServerCustomValidationRequested(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ClearAuthenticationCache(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter4) -> Void: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilter5) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def SendRequestAsync(self: win32more.Windows.Web.Http.Filters.IHttpFilter, request: win32more.Windows.Web.Http.HttpRequestMessage) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Web.Http.HttpResponseMessage, win32more.Windows.Web.Http.HttpProgress]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def CreateForUser(cls: win32more.Windows.Web.Http.Filters.IHttpBaseProtocolFilterStatics, user: win32more.Windows.System.User) -> win32more.Windows.Web.Http.Filters.HttpBaseProtocolFilter: ...
    AllowAutoRedirect = property(get_AllowAutoRedirect, put_AllowAutoRedirect)
    AllowUI = property(get_AllowUI, put_AllowUI)
    AutomaticDecompression = property(get_AutomaticDecompression, put_AutomaticDecompression)
    CacheControl = property(get_CacheControl, None)
    ClientCertificate = property(get_ClientCertificate, put_ClientCertificate)
    CookieManager = property(get_CookieManager, None)
    CookieUsageBehavior = property(get_CookieUsageBehavior, put_CookieUsageBehavior)
    IgnorableServerCertificateErrors = property(get_IgnorableServerCertificateErrors, None)
    MaxConnectionsPerServer = property(get_MaxConnectionsPerServer, put_MaxConnectionsPerServer)
    MaxVersion = property(get_MaxVersion, put_MaxVersion)
    ProxyCredential = property(get_ProxyCredential, put_ProxyCredential)
    ServerCredential = property(get_ServerCredential, put_ServerCredential)
    UseProxy = property(get_UseProxy, put_UseProxy)
    User = property(get_User, None)
    ServerCustomValidationRequested = event()
class HttpCacheControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.Http.Filters.IHttpCacheControl
    _classid_ = 'Windows.Web.Http.Filters.HttpCacheControl'
    @winrt_mixinmethod
    def get_ReadBehavior(self: win32more.Windows.Web.Http.Filters.IHttpCacheControl) -> win32more.Windows.Web.Http.Filters.HttpCacheReadBehavior: ...
    @winrt_mixinmethod
    def put_ReadBehavior(self: win32more.Windows.Web.Http.Filters.IHttpCacheControl, value: win32more.Windows.Web.Http.Filters.HttpCacheReadBehavior) -> Void: ...
    @winrt_mixinmethod
    def get_WriteBehavior(self: win32more.Windows.Web.Http.Filters.IHttpCacheControl) -> win32more.Windows.Web.Http.Filters.HttpCacheWriteBehavior: ...
    @winrt_mixinmethod
    def put_WriteBehavior(self: win32more.Windows.Web.Http.Filters.IHttpCacheControl, value: win32more.Windows.Web.Http.Filters.HttpCacheWriteBehavior) -> Void: ...
    ReadBehavior = property(get_ReadBehavior, put_ReadBehavior)
    WriteBehavior = property(get_WriteBehavior, put_WriteBehavior)
class HttpCacheReadBehavior(Enum, Int32):
    Default = 0
    MostRecent = 1
    OnlyFromCache = 2
    NoCache = 3
class HttpCacheWriteBehavior(Enum, Int32):
    Default = 0
    NoCache = 1
class HttpCookieUsageBehavior(Enum, Int32):
    Default = 0
    NoCookies = 1
class HttpServerCustomValidationRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs
    _classid_ = 'Windows.Web.Http.Filters.HttpServerCustomValidationRequestedEventArgs'
    @winrt_mixinmethod
    def get_RequestMessage(self: win32more.Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs) -> win32more.Windows.Web.Http.HttpRequestMessage: ...
    @winrt_mixinmethod
    def get_ServerCertificate(self: win32more.Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs) -> win32more.Windows.Security.Cryptography.Certificates.Certificate: ...
    @winrt_mixinmethod
    def get_ServerCertificateErrorSeverity(self: win32more.Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs) -> win32more.Windows.Networking.Sockets.SocketSslErrorSeverity: ...
    @winrt_mixinmethod
    def get_ServerCertificateErrors(self: win32more.Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Security.Cryptography.Certificates.ChainValidationResult]: ...
    @winrt_mixinmethod
    def get_ServerIntermediateCertificates(self: win32more.Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Security.Cryptography.Certificates.Certificate]: ...
    @winrt_mixinmethod
    def Reject(self: win32more.Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    RequestMessage = property(get_RequestMessage, None)
    ServerCertificate = property(get_ServerCertificate, None)
    ServerCertificateErrorSeverity = property(get_ServerCertificateErrorSeverity, None)
    ServerCertificateErrors = property(get_ServerCertificateErrors, None)
    ServerIntermediateCertificates = property(get_ServerIntermediateCertificates, None)
class IHttpBaseProtocolFilter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.Http.Filters.IHttpBaseProtocolFilter'
    _iid_ = Guid('{71c89b09-e131-4b54-a53c-eb43ff37e9bb}')
    @winrt_commethod(6)
    def get_AllowAutoRedirect(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AllowAutoRedirect(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_AllowUI(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_AllowUI(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_AutomaticDecompression(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_AutomaticDecompression(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_CacheControl(self) -> win32more.Windows.Web.Http.Filters.HttpCacheControl: ...
    @winrt_commethod(13)
    def get_CookieManager(self) -> win32more.Windows.Web.Http.HttpCookieManager: ...
    @winrt_commethod(14)
    def get_ClientCertificate(self) -> win32more.Windows.Security.Cryptography.Certificates.Certificate: ...
    @winrt_commethod(15)
    def put_ClientCertificate(self, value: win32more.Windows.Security.Cryptography.Certificates.Certificate) -> Void: ...
    @winrt_commethod(16)
    def get_IgnorableServerCertificateErrors(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Security.Cryptography.Certificates.ChainValidationResult]: ...
    @winrt_commethod(17)
    def get_MaxConnectionsPerServer(self) -> UInt32: ...
    @winrt_commethod(18)
    def put_MaxConnectionsPerServer(self, value: UInt32) -> Void: ...
    @winrt_commethod(19)
    def get_ProxyCredential(self) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_commethod(20)
    def put_ProxyCredential(self, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    @winrt_commethod(21)
    def get_ServerCredential(self) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_commethod(22)
    def put_ServerCredential(self, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    @winrt_commethod(23)
    def get_UseProxy(self) -> Boolean: ...
    @winrt_commethod(24)
    def put_UseProxy(self, value: Boolean) -> Void: ...
    AllowAutoRedirect = property(get_AllowAutoRedirect, put_AllowAutoRedirect)
    AllowUI = property(get_AllowUI, put_AllowUI)
    AutomaticDecompression = property(get_AutomaticDecompression, put_AutomaticDecompression)
    CacheControl = property(get_CacheControl, None)
    ClientCertificate = property(get_ClientCertificate, put_ClientCertificate)
    CookieManager = property(get_CookieManager, None)
    IgnorableServerCertificateErrors = property(get_IgnorableServerCertificateErrors, None)
    MaxConnectionsPerServer = property(get_MaxConnectionsPerServer, put_MaxConnectionsPerServer)
    ProxyCredential = property(get_ProxyCredential, put_ProxyCredential)
    ServerCredential = property(get_ServerCredential, put_ServerCredential)
    UseProxy = property(get_UseProxy, put_UseProxy)
class IHttpBaseProtocolFilter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.Http.Filters.IHttpBaseProtocolFilter2'
    _iid_ = Guid('{2ec30013-9427-4900-a017-fa7da3b5c9ae}')
    @winrt_commethod(6)
    def get_MaxVersion(self) -> win32more.Windows.Web.Http.HttpVersion: ...
    @winrt_commethod(7)
    def put_MaxVersion(self, value: win32more.Windows.Web.Http.HttpVersion) -> Void: ...
    MaxVersion = property(get_MaxVersion, put_MaxVersion)
class IHttpBaseProtocolFilter3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.Http.Filters.IHttpBaseProtocolFilter3'
    _iid_ = Guid('{d43f4d4c-bd42-43ae-8717-ad2c8f4b2937}')
    @winrt_commethod(6)
    def get_CookieUsageBehavior(self) -> win32more.Windows.Web.Http.Filters.HttpCookieUsageBehavior: ...
    @winrt_commethod(7)
    def put_CookieUsageBehavior(self, value: win32more.Windows.Web.Http.Filters.HttpCookieUsageBehavior) -> Void: ...
    CookieUsageBehavior = property(get_CookieUsageBehavior, put_CookieUsageBehavior)
class IHttpBaseProtocolFilter4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.Http.Filters.IHttpBaseProtocolFilter4'
    _iid_ = Guid('{9fe36ccf-2983-4893-941f-eb518ca8cef9}')
    @winrt_commethod(6)
    def add_ServerCustomValidationRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Web.Http.Filters.HttpBaseProtocolFilter, win32more.Windows.Web.Http.Filters.HttpServerCustomValidationRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ServerCustomValidationRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def ClearAuthenticationCache(self) -> Void: ...
    ServerCustomValidationRequested = event()
class IHttpBaseProtocolFilter5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.Http.Filters.IHttpBaseProtocolFilter5'
    _iid_ = Guid('{416e4993-31e3-4816-bf09-e018ee8dc1f5}')
    @winrt_commethod(6)
    def get_User(self) -> win32more.Windows.System.User: ...
    User = property(get_User, None)
class IHttpBaseProtocolFilterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.Http.Filters.IHttpBaseProtocolFilterStatics'
    _iid_ = Guid('{6d4dee0c-e908-494e-b5a3-1263c9b8242a}')
    @winrt_commethod(6)
    def CreateForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Web.Http.Filters.HttpBaseProtocolFilter: ...
class IHttpCacheControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.Http.Filters.IHttpCacheControl'
    _iid_ = Guid('{c77e1cb4-3cea-4eb5-ac85-04e186e63ab7}')
    @winrt_commethod(6)
    def get_ReadBehavior(self) -> win32more.Windows.Web.Http.Filters.HttpCacheReadBehavior: ...
    @winrt_commethod(7)
    def put_ReadBehavior(self, value: win32more.Windows.Web.Http.Filters.HttpCacheReadBehavior) -> Void: ...
    @winrt_commethod(8)
    def get_WriteBehavior(self) -> win32more.Windows.Web.Http.Filters.HttpCacheWriteBehavior: ...
    @winrt_commethod(9)
    def put_WriteBehavior(self, value: win32more.Windows.Web.Http.Filters.HttpCacheWriteBehavior) -> Void: ...
    ReadBehavior = property(get_ReadBehavior, put_ReadBehavior)
    WriteBehavior = property(get_WriteBehavior, put_WriteBehavior)
class IHttpFilter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Web.Http.Filters.IHttpFilter'
    _iid_ = Guid('{a4cb6dd5-0902-439e-bfd7-e12552b165ce}')
    @winrt_commethod(6)
    def SendRequestAsync(self, request: win32more.Windows.Web.Http.HttpRequestMessage) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Web.Http.HttpResponseMessage, win32more.Windows.Web.Http.HttpProgress]: ...
class IHttpServerCustomValidationRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Web.Http.Filters.IHttpServerCustomValidationRequestedEventArgs'
    _iid_ = Guid('{3165fe32-e7dd-48b7-a361-939c750e63cc}')
    @winrt_commethod(6)
    def get_RequestMessage(self) -> win32more.Windows.Web.Http.HttpRequestMessage: ...
    @winrt_commethod(7)
    def get_ServerCertificate(self) -> win32more.Windows.Security.Cryptography.Certificates.Certificate: ...
    @winrt_commethod(8)
    def get_ServerCertificateErrorSeverity(self) -> win32more.Windows.Networking.Sockets.SocketSslErrorSeverity: ...
    @winrt_commethod(9)
    def get_ServerCertificateErrors(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Security.Cryptography.Certificates.ChainValidationResult]: ...
    @winrt_commethod(10)
    def get_ServerIntermediateCertificates(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Security.Cryptography.Certificates.Certificate]: ...
    @winrt_commethod(11)
    def Reject(self) -> Void: ...
    @winrt_commethod(12)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    RequestMessage = property(get_RequestMessage, None)
    ServerCertificate = property(get_ServerCertificate, None)
    ServerCertificateErrorSeverity = property(get_ServerCertificateErrorSeverity, None)
    ServerCertificateErrors = property(get_ServerCertificateErrors, None)
    ServerIntermediateCertificates = property(get_ServerIntermediateCertificates, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.NetworkManagement.NetBios
class ACTION_HEADER(Structure):
    transport_id: UInt32
    action_code: UInt16
    reserved: UInt16
class ADAPTER_STATUS(Structure):
    adapter_address: Byte * 6
    rev_major: Byte
    reserved0: Byte
    adapter_type: Byte
    rev_minor: Byte
    duration: UInt16
    frmr_recv: UInt16
    frmr_xmit: UInt16
    iframe_recv_err: UInt16
    xmit_aborts: UInt16
    xmit_success: UInt32
    recv_success: UInt32
    iframe_xmit_err: UInt16
    recv_buff_unavail: UInt16
    t1_timeouts: UInt16
    ti_timeouts: UInt16
    reserved1: UInt32
    free_ncbs: UInt16
    max_cfg_ncbs: UInt16
    max_ncbs: UInt16
    xmit_buf_unavail: UInt16
    max_dgram_size: UInt16
    pending_sess: UInt16
    max_cfg_sess: UInt16
    max_sess: UInt16
    max_sess_pkt_size: UInt16
    name_count: UInt16
NCBNAMSZ: UInt32 = 16
MAX_LANA: UInt32 = 254
NAME_FLAGS_MASK: UInt32 = 135
GROUP_NAME: UInt32 = 128
UNIQUE_NAME: UInt32 = 0
REGISTERING: UInt32 = 0
REGISTERED: UInt32 = 4
DEREGISTERED: UInt32 = 5
DUPLICATE: UInt32 = 6
DUPLICATE_DEREG: UInt32 = 7
LISTEN_OUTSTANDING: UInt32 = 1
CALL_PENDING: UInt32 = 2
SESSION_ESTABLISHED: UInt32 = 3
HANGUP_PENDING: UInt32 = 4
HANGUP_COMPLETE: UInt32 = 5
SESSION_ABORTED: UInt32 = 6
ALL_TRANSPORTS: String = 'M\x00\x00\x00'
MS_NBF: String = 'MNBF'
NCBCALL: UInt32 = 16
NCBLISTEN: UInt32 = 17
NCBHANGUP: UInt32 = 18
NCBSEND: UInt32 = 20
NCBRECV: UInt32 = 21
NCBRECVANY: UInt32 = 22
NCBCHAINSEND: UInt32 = 23
NCBDGSEND: UInt32 = 32
NCBDGRECV: UInt32 = 33
NCBDGSENDBC: UInt32 = 34
NCBDGRECVBC: UInt32 = 35
NCBADDNAME: UInt32 = 48
NCBDELNAME: UInt32 = 49
NCBRESET: UInt32 = 50
NCBASTAT: UInt32 = 51
NCBSSTAT: UInt32 = 52
NCBCANCEL: UInt32 = 53
NCBADDGRNAME: UInt32 = 54
NCBENUM: UInt32 = 55
NCBUNLINK: UInt32 = 112
NCBSENDNA: UInt32 = 113
NCBCHAINSENDNA: UInt32 = 114
NCBLANSTALERT: UInt32 = 115
NCBACTION: UInt32 = 119
NCBFINDNAME: UInt32 = 120
NCBTRACE: UInt32 = 121
ASYNCH: UInt32 = 128
NRC_GOODRET: UInt32 = 0
NRC_BUFLEN: UInt32 = 1
NRC_ILLCMD: UInt32 = 3
NRC_CMDTMO: UInt32 = 5
NRC_INCOMP: UInt32 = 6
NRC_BADDR: UInt32 = 7
NRC_SNUMOUT: UInt32 = 8
NRC_NORES: UInt32 = 9
NRC_SCLOSED: UInt32 = 10
NRC_CMDCAN: UInt32 = 11
NRC_DUPNAME: UInt32 = 13
NRC_NAMTFUL: UInt32 = 14
NRC_ACTSES: UInt32 = 15
NRC_LOCTFUL: UInt32 = 17
NRC_REMTFUL: UInt32 = 18
NRC_ILLNN: UInt32 = 19
NRC_NOCALL: UInt32 = 20
NRC_NOWILD: UInt32 = 21
NRC_INUSE: UInt32 = 22
NRC_NAMERR: UInt32 = 23
NRC_SABORT: UInt32 = 24
NRC_NAMCONF: UInt32 = 25
NRC_IFBUSY: UInt32 = 33
NRC_TOOMANY: UInt32 = 34
NRC_BRIDGE: UInt32 = 35
NRC_CANOCCR: UInt32 = 36
NRC_CANCEL: UInt32 = 38
NRC_DUPENV: UInt32 = 48
NRC_ENVNOTDEF: UInt32 = 52
NRC_OSRESNOTAV: UInt32 = 53
NRC_MAXAPPS: UInt32 = 54
NRC_NOSAPS: UInt32 = 55
NRC_NORESOURCES: UInt32 = 56
NRC_INVADDRESS: UInt32 = 57
NRC_INVDDID: UInt32 = 59
NRC_LOCKFAIL: UInt32 = 60
NRC_OPENERR: UInt32 = 63
NRC_SYSTEM: UInt32 = 64
NRC_PENDING: UInt32 = 255
@winfunctype('NETAPI32.dll')
def Netbios(pncb: POINTER(win32more.Windows.Win32.NetworkManagement.NetBios.NCB)) -> Byte: ...
class FIND_NAME_BUFFER(Structure):
    length: Byte
    access_control: Byte
    frame_control: Byte
    destination_addr: Byte * 6
    source_addr: Byte * 6
    routing_info: Byte * 18
class FIND_NAME_HEADER(Structure):
    node_count: UInt16
    reserved: Byte
    unique_group: Byte
class LANA_ENUM(Structure):
    length: Byte
    lana: Byte * 255
class NAME_BUFFER(Structure):
    name: Byte * 16
    name_num: Byte
    name_flags: Byte
if ARCH in 'X64,ARM64':
    class NCB(Structure):
        ncb_command: Byte
        ncb_retcode: Byte
        ncb_lsn: Byte
        ncb_num: Byte
        ncb_buffer: POINTER(Byte)
        ncb_length: UInt16
        ncb_callname: Byte * 16
        ncb_name: Byte * 16
        ncb_rto: Byte
        ncb_sto: Byte
        ncb_post: IntPtr
        ncb_lana_num: Byte
        ncb_cmd_cplt: Byte
        ncb_reserve: Byte * 18
        ncb_event: win32more.Windows.Win32.Foundation.HANDLE
elif ARCH in 'X86':
    class NCB(Structure):
        ncb_command: Byte
        ncb_retcode: Byte
        ncb_lsn: Byte
        ncb_num: Byte
        ncb_buffer: POINTER(Byte)
        ncb_length: UInt16
        ncb_callname: Byte * 16
        ncb_name: Byte * 16
        ncb_rto: Byte
        ncb_sto: Byte
        ncb_post: IntPtr
        ncb_lana_num: Byte
        ncb_cmd_cplt: Byte
        ncb_reserve: Byte * 10
        ncb_event: win32more.Windows.Win32.Foundation.HANDLE
class SESSION_BUFFER(Structure):
    lsn: Byte
    state: Byte
    local_name: Byte * 16
    remote_name: Byte * 16
    rcvs_outstanding: Byte
    sends_outstanding: Byte
class SESSION_HEADER(Structure):
    sess_name: Byte
    num_sess: Byte
    rcv_dg_outstanding: Byte
    rcv_any_outstanding: Byte


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Registry
import win32more.Windows.Win32.System.Services
SERVICE_ALL_ACCESS: UInt32 = 983551
SC_MANAGER_ALL_ACCESS: UInt32 = 983103
SERVICES_ACTIVE_DATABASEW: String = 'ServicesActive'
SERVICES_FAILED_DATABASEW: String = 'ServicesFailed'
SERVICES_ACTIVE_DATABASEA: String = 'ServicesActive'
SERVICES_FAILED_DATABASEA: String = 'ServicesFailed'
SERVICES_ACTIVE_DATABASE: String = 'ServicesActive'
SERVICES_FAILED_DATABASE: String = 'ServicesFailed'
SERVICE_NO_CHANGE: UInt32 = 4294967295
SERVICE_CONTROL_STOP: UInt32 = 1
SERVICE_CONTROL_PAUSE: UInt32 = 2
SERVICE_CONTROL_CONTINUE: UInt32 = 3
SERVICE_CONTROL_INTERROGATE: UInt32 = 4
SERVICE_CONTROL_SHUTDOWN: UInt32 = 5
SERVICE_CONTROL_PARAMCHANGE: UInt32 = 6
SERVICE_CONTROL_NETBINDADD: UInt32 = 7
SERVICE_CONTROL_NETBINDREMOVE: UInt32 = 8
SERVICE_CONTROL_NETBINDENABLE: UInt32 = 9
SERVICE_CONTROL_NETBINDDISABLE: UInt32 = 10
SERVICE_CONTROL_DEVICEEVENT: UInt32 = 11
SERVICE_CONTROL_HARDWAREPROFILECHANGE: UInt32 = 12
SERVICE_CONTROL_POWEREVENT: UInt32 = 13
SERVICE_CONTROL_SESSIONCHANGE: UInt32 = 14
SERVICE_CONTROL_PRESHUTDOWN: UInt32 = 15
SERVICE_CONTROL_TIMECHANGE: UInt32 = 16
SERVICE_CONTROL_TRIGGEREVENT: UInt32 = 32
SERVICE_CONTROL_LOWRESOURCES: UInt32 = 96
SERVICE_CONTROL_SYSTEMLOWRESOURCES: UInt32 = 97
SERVICE_ACCEPT_STOP: UInt32 = 1
SERVICE_ACCEPT_PAUSE_CONTINUE: UInt32 = 2
SERVICE_ACCEPT_SHUTDOWN: UInt32 = 4
SERVICE_ACCEPT_PARAMCHANGE: UInt32 = 8
SERVICE_ACCEPT_NETBINDCHANGE: UInt32 = 16
SERVICE_ACCEPT_HARDWAREPROFILECHANGE: UInt32 = 32
SERVICE_ACCEPT_POWEREVENT: UInt32 = 64
SERVICE_ACCEPT_SESSIONCHANGE: UInt32 = 128
SERVICE_ACCEPT_PRESHUTDOWN: UInt32 = 256
SERVICE_ACCEPT_TIMECHANGE: UInt32 = 512
SERVICE_ACCEPT_TRIGGEREVENT: UInt32 = 1024
SERVICE_ACCEPT_USER_LOGOFF: UInt32 = 2048
SERVICE_ACCEPT_LOWRESOURCES: UInt32 = 8192
SERVICE_ACCEPT_SYSTEMLOWRESOURCES: UInt32 = 16384
SC_MANAGER_CONNECT: UInt32 = 1
SC_MANAGER_CREATE_SERVICE: UInt32 = 2
SC_MANAGER_ENUMERATE_SERVICE: UInt32 = 4
SC_MANAGER_LOCK: UInt32 = 8
SC_MANAGER_QUERY_LOCK_STATUS: UInt32 = 16
SC_MANAGER_MODIFY_BOOT_CONFIG: UInt32 = 32
SERVICE_QUERY_CONFIG: UInt32 = 1
SERVICE_CHANGE_CONFIG: UInt32 = 2
SERVICE_QUERY_STATUS: UInt32 = 4
SERVICE_ENUMERATE_DEPENDENTS: UInt32 = 8
SERVICE_START: UInt32 = 16
SERVICE_STOP: UInt32 = 32
SERVICE_PAUSE_CONTINUE: UInt32 = 64
SERVICE_INTERROGATE: UInt32 = 128
SERVICE_USER_DEFINED_CONTROL: UInt32 = 256
SERVICE_NOTIFY_STATUS_CHANGE_1: UInt32 = 1
SERVICE_NOTIFY_STATUS_CHANGE_2: UInt32 = 2
SERVICE_NOTIFY_STATUS_CHANGE: UInt32 = 2
SERVICE_STOP_REASON_FLAG_MIN: UInt32 = 0
SERVICE_STOP_REASON_FLAG_UNPLANNED: UInt32 = 268435456
SERVICE_STOP_REASON_FLAG_CUSTOM: UInt32 = 536870912
SERVICE_STOP_REASON_FLAG_PLANNED: UInt32 = 1073741824
SERVICE_STOP_REASON_FLAG_MAX: UInt32 = 2147483648
SERVICE_STOP_REASON_MAJOR_MIN: UInt32 = 0
SERVICE_STOP_REASON_MAJOR_OTHER: UInt32 = 65536
SERVICE_STOP_REASON_MAJOR_HARDWARE: UInt32 = 131072
SERVICE_STOP_REASON_MAJOR_OPERATINGSYSTEM: UInt32 = 196608
SERVICE_STOP_REASON_MAJOR_SOFTWARE: UInt32 = 262144
SERVICE_STOP_REASON_MAJOR_APPLICATION: UInt32 = 327680
SERVICE_STOP_REASON_MAJOR_NONE: UInt32 = 393216
SERVICE_STOP_REASON_MAJOR_MAX: UInt32 = 458752
SERVICE_STOP_REASON_MAJOR_MIN_CUSTOM: UInt32 = 4194304
SERVICE_STOP_REASON_MAJOR_MAX_CUSTOM: UInt32 = 16711680
SERVICE_STOP_REASON_MINOR_MIN: UInt32 = 0
SERVICE_STOP_REASON_MINOR_OTHER: UInt32 = 1
SERVICE_STOP_REASON_MINOR_MAINTENANCE: UInt32 = 2
SERVICE_STOP_REASON_MINOR_INSTALLATION: UInt32 = 3
SERVICE_STOP_REASON_MINOR_UPGRADE: UInt32 = 4
SERVICE_STOP_REASON_MINOR_RECONFIG: UInt32 = 5
SERVICE_STOP_REASON_MINOR_HUNG: UInt32 = 6
SERVICE_STOP_REASON_MINOR_UNSTABLE: UInt32 = 7
SERVICE_STOP_REASON_MINOR_DISK: UInt32 = 8
SERVICE_STOP_REASON_MINOR_NETWORKCARD: UInt32 = 9
SERVICE_STOP_REASON_MINOR_ENVIRONMENT: UInt32 = 10
SERVICE_STOP_REASON_MINOR_HARDWARE_DRIVER: UInt32 = 11
SERVICE_STOP_REASON_MINOR_OTHERDRIVER: UInt32 = 12
SERVICE_STOP_REASON_MINOR_SERVICEPACK: UInt32 = 13
SERVICE_STOP_REASON_MINOR_SOFTWARE_UPDATE: UInt32 = 14
SERVICE_STOP_REASON_MINOR_SECURITYFIX: UInt32 = 15
SERVICE_STOP_REASON_MINOR_SECURITY: UInt32 = 16
SERVICE_STOP_REASON_MINOR_NETWORK_CONNECTIVITY: UInt32 = 17
SERVICE_STOP_REASON_MINOR_WMI: UInt32 = 18
SERVICE_STOP_REASON_MINOR_SERVICEPACK_UNINSTALL: UInt32 = 19
SERVICE_STOP_REASON_MINOR_SOFTWARE_UPDATE_UNINSTALL: UInt32 = 20
SERVICE_STOP_REASON_MINOR_SECURITYFIX_UNINSTALL: UInt32 = 21
SERVICE_STOP_REASON_MINOR_MMC: UInt32 = 22
SERVICE_STOP_REASON_MINOR_NONE: UInt32 = 23
SERVICE_STOP_REASON_MINOR_MEMOTYLIMIT: UInt32 = 24
SERVICE_STOP_REASON_MINOR_MAX: UInt32 = 25
SERVICE_STOP_REASON_MINOR_MIN_CUSTOM: UInt32 = 256
SERVICE_STOP_REASON_MINOR_MAX_CUSTOM: UInt32 = 65535
SERVICE_CONTROL_STATUS_REASON_INFO: UInt32 = 1
SERVICE_SID_TYPE_NONE: UInt32 = 0
SERVICE_SID_TYPE_UNRESTRICTED: UInt32 = 1
SERVICE_TRIGGER_TYPE_CUSTOM_SYSTEM_STATE_CHANGE: UInt32 = 7
SERVICE_TRIGGER_TYPE_AGGREGATE: UInt32 = 30
SERVICE_START_REASON_DEMAND: UInt32 = 1
SERVICE_START_REASON_AUTO: UInt32 = 2
SERVICE_START_REASON_TRIGGER: UInt32 = 4
SERVICE_START_REASON_RESTART_ON_FAILURE: UInt32 = 8
SERVICE_START_REASON_DELAYEDAUTO: UInt32 = 16
SERVICE_DYNAMIC_INFORMATION_LEVEL_START_REASON: UInt32 = 1
SERVICE_LAUNCH_PROTECTED_NONE: UInt32 = 0
SERVICE_LAUNCH_PROTECTED_WINDOWS: UInt32 = 1
SERVICE_LAUNCH_PROTECTED_WINDOWS_LIGHT: UInt32 = 2
SERVICE_LAUNCH_PROTECTED_ANTIMALWARE_LIGHT: UInt32 = 3
NETWORK_MANAGER_FIRST_IP_ADDRESS_ARRIVAL_GUID: Guid = Guid('{4f27f2de-14e2-430b-a549-7cd48cbc8245}')
NETWORK_MANAGER_LAST_IP_ADDRESS_REMOVAL_GUID: Guid = Guid('{cc4ba62a-162e-4648-847a-b6bdf993e335}')
DOMAIN_JOIN_GUID: Guid = Guid('{1ce20aba-9851-4421-9430-1ddeb766e809}')
DOMAIN_LEAVE_GUID: Guid = Guid('{ddaf516e-58c2-4866-9574-c3b615d42ea1}')
FIREWALL_PORT_OPEN_GUID: Guid = Guid('{b7569e07-8421-4ee0-ad10-86915afdad09}')
FIREWALL_PORT_CLOSE_GUID: Guid = Guid('{a144ed38-8e12-4de4-9d96-e64740b1a524}')
MACHINE_POLICY_PRESENT_GUID: Guid = Guid('{659fcae6-5bdb-4da9-b1ff-ca2a178d46e0}')
USER_POLICY_PRESENT_GUID: Guid = Guid('{54fb46c8-f089-464c-b1fd-59d1b62c3b50}')
RPC_INTERFACE_EVENT_GUID: Guid = Guid('{bc90d167-9470-4139-a9ba-be0bbbf5b74d}')
NAMED_PIPE_EVENT_GUID: Guid = Guid('{1f81d131-3fac-4537-9e0c-7e7b0c2f4b55}')
CUSTOM_SYSTEM_STATE_CHANGE_EVENT_GUID: Guid = Guid('{2d7a2816-0c5e-45fc-9ce7-570e5ecde9c9}')
SERVICE_TRIGGER_STARTED_ARGUMENT: String = 'TriggerStarted'
SC_AGGREGATE_STORAGE_KEY: String = 'System\\CurrentControlSet\\Control\\ServiceAggregatedEvents'
@winfunctype('ADVAPI32.dll')
def SetServiceBits(hServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE, dwServiceBits: UInt32, bSetBitsOn: win32more.Windows.Win32.Foundation.BOOL, bUpdateImmediately: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ChangeServiceConfigA(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE, dwStartType: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE, dwErrorControl: win32more.Windows.Win32.System.Services.SERVICE_ERROR, lpBinaryPathName: win32more.Windows.Win32.Foundation.PSTR, lpLoadOrderGroup: win32more.Windows.Win32.Foundation.PSTR, lpdwTagId: POINTER(UInt32), lpDependencies: win32more.Windows.Win32.Foundation.PSTR, lpServiceStartName: win32more.Windows.Win32.Foundation.PSTR, lpPassword: win32more.Windows.Win32.Foundation.PSTR, lpDisplayName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ChangeServiceConfigW(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE, dwStartType: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE, dwErrorControl: win32more.Windows.Win32.System.Services.SERVICE_ERROR, lpBinaryPathName: win32more.Windows.Win32.Foundation.PWSTR, lpLoadOrderGroup: win32more.Windows.Win32.Foundation.PWSTR, lpdwTagId: POINTER(UInt32), lpDependencies: win32more.Windows.Win32.Foundation.PWSTR, lpServiceStartName: win32more.Windows.Win32.Foundation.PWSTR, lpPassword: win32more.Windows.Win32.Foundation.PWSTR, lpDisplayName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
ChangeServiceConfig = UnicodeAlias('ChangeServiceConfigW')
@winfunctype('ADVAPI32.dll')
def ChangeServiceConfig2A(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwInfoLevel: win32more.Windows.Win32.System.Services.SERVICE_CONFIG, lpInfo: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ChangeServiceConfig2W(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwInfoLevel: win32more.Windows.Win32.System.Services.SERVICE_CONFIG, lpInfo: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
ChangeServiceConfig2 = UnicodeAlias('ChangeServiceConfig2W')
@winfunctype('ADVAPI32.dll')
def CloseServiceHandle(hSCObject: win32more.Windows.Win32.System.Services.SC_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ControlService(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwControl: UInt32, lpServiceStatus: POINTER(win32more.Windows.Win32.System.Services.SERVICE_STATUS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def CreateServiceA(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceName: win32more.Windows.Win32.Foundation.PSTR, lpDisplayName: win32more.Windows.Win32.Foundation.PSTR, dwDesiredAccess: UInt32, dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE, dwStartType: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE, dwErrorControl: win32more.Windows.Win32.System.Services.SERVICE_ERROR, lpBinaryPathName: win32more.Windows.Win32.Foundation.PSTR, lpLoadOrderGroup: win32more.Windows.Win32.Foundation.PSTR, lpdwTagId: POINTER(UInt32), lpDependencies: win32more.Windows.Win32.Foundation.PSTR, lpServiceStartName: win32more.Windows.Win32.Foundation.PSTR, lpPassword: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.System.Services.SC_HANDLE: ...
@winfunctype('ADVAPI32.dll')
def CreateServiceW(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceName: win32more.Windows.Win32.Foundation.PWSTR, lpDisplayName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE, dwStartType: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE, dwErrorControl: win32more.Windows.Win32.System.Services.SERVICE_ERROR, lpBinaryPathName: win32more.Windows.Win32.Foundation.PWSTR, lpLoadOrderGroup: win32more.Windows.Win32.Foundation.PWSTR, lpdwTagId: POINTER(UInt32), lpDependencies: win32more.Windows.Win32.Foundation.PWSTR, lpServiceStartName: win32more.Windows.Win32.Foundation.PWSTR, lpPassword: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.System.Services.SC_HANDLE: ...
CreateService = UnicodeAlias('CreateServiceW')
@winfunctype('ADVAPI32.dll')
def DeleteService(hService: win32more.Windows.Win32.System.Services.SC_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def EnumDependentServicesA(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwServiceState: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE, lpServices: POINTER(win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATUSA), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32), lpServicesReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def EnumDependentServicesW(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwServiceState: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE, lpServices: POINTER(win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATUSW), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32), lpServicesReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumDependentServices = UnicodeAlias('EnumDependentServicesW')
@winfunctype('ADVAPI32.dll')
def EnumServicesStatusA(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE, dwServiceState: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE, lpServices: POINTER(win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATUSA), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32), lpServicesReturned: POINTER(UInt32), lpResumeHandle: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def EnumServicesStatusW(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE, dwServiceState: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE, lpServices: POINTER(win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATUSW), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32), lpServicesReturned: POINTER(UInt32), lpResumeHandle: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumServicesStatus = UnicodeAlias('EnumServicesStatusW')
@winfunctype('ADVAPI32.dll')
def EnumServicesStatusExA(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, InfoLevel: win32more.Windows.Win32.System.Services.SC_ENUM_TYPE, dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE, dwServiceState: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE, lpServices: POINTER(Byte), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32), lpServicesReturned: POINTER(UInt32), lpResumeHandle: POINTER(UInt32), pszGroupName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def EnumServicesStatusExW(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, InfoLevel: win32more.Windows.Win32.System.Services.SC_ENUM_TYPE, dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE, dwServiceState: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE, lpServices: POINTER(Byte), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32), lpServicesReturned: POINTER(UInt32), lpResumeHandle: POINTER(UInt32), pszGroupName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumServicesStatusEx = UnicodeAlias('EnumServicesStatusExW')
@winfunctype('ADVAPI32.dll')
def GetServiceKeyNameA(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpDisplayName: win32more.Windows.Win32.Foundation.PSTR, lpServiceName: win32more.Windows.Win32.Foundation.PSTR, lpcchBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def GetServiceKeyNameW(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpDisplayName: win32more.Windows.Win32.Foundation.PWSTR, lpServiceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetServiceKeyName = UnicodeAlias('GetServiceKeyNameW')
@winfunctype('ADVAPI32.dll')
def GetServiceDisplayNameA(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceName: win32more.Windows.Win32.Foundation.PSTR, lpDisplayName: win32more.Windows.Win32.Foundation.PSTR, lpcchBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def GetServiceDisplayNameW(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceName: win32more.Windows.Win32.Foundation.PWSTR, lpDisplayName: win32more.Windows.Win32.Foundation.PWSTR, lpcchBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetServiceDisplayName = UnicodeAlias('GetServiceDisplayNameW')
@winfunctype('ADVAPI32.dll')
def LockServiceDatabase(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE) -> VoidPtr: ...
@winfunctype('ADVAPI32.dll')
def NotifyBootConfigStatus(BootAcceptable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def OpenSCManagerA(lpMachineName: win32more.Windows.Win32.Foundation.PSTR, lpDatabaseName: win32more.Windows.Win32.Foundation.PSTR, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.System.Services.SC_HANDLE: ...
@winfunctype('ADVAPI32.dll')
def OpenSCManagerW(lpMachineName: win32more.Windows.Win32.Foundation.PWSTR, lpDatabaseName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.System.Services.SC_HANDLE: ...
OpenSCManager = UnicodeAlias('OpenSCManagerW')
@winfunctype('ADVAPI32.dll')
def OpenServiceA(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceName: win32more.Windows.Win32.Foundation.PSTR, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.System.Services.SC_HANDLE: ...
@winfunctype('ADVAPI32.dll')
def OpenServiceW(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.System.Services.SC_HANDLE: ...
OpenService = UnicodeAlias('OpenServiceW')
@winfunctype('ADVAPI32.dll')
def QueryServiceConfigA(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceConfig: POINTER(win32more.Windows.Win32.System.Services.QUERY_SERVICE_CONFIGA), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def QueryServiceConfigW(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceConfig: POINTER(win32more.Windows.Win32.System.Services.QUERY_SERVICE_CONFIGW), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
QueryServiceConfig = UnicodeAlias('QueryServiceConfigW')
@winfunctype('ADVAPI32.dll')
def QueryServiceConfig2A(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwInfoLevel: win32more.Windows.Win32.System.Services.SERVICE_CONFIG, lpBuffer: POINTER(Byte), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def QueryServiceConfig2W(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwInfoLevel: win32more.Windows.Win32.System.Services.SERVICE_CONFIG, lpBuffer: POINTER(Byte), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
QueryServiceConfig2 = UnicodeAlias('QueryServiceConfig2W')
@winfunctype('ADVAPI32.dll')
def QueryServiceLockStatusA(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpLockStatus: POINTER(win32more.Windows.Win32.System.Services.QUERY_SERVICE_LOCK_STATUSA), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def QueryServiceLockStatusW(hSCManager: win32more.Windows.Win32.System.Services.SC_HANDLE, lpLockStatus: POINTER(win32more.Windows.Win32.System.Services.QUERY_SERVICE_LOCK_STATUSW), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
QueryServiceLockStatus = UnicodeAlias('QueryServiceLockStatusW')
@winfunctype('ADVAPI32.dll')
def QueryServiceObjectSecurity(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwSecurityInformation: UInt32, lpSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def QueryServiceStatus(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, lpServiceStatus: POINTER(win32more.Windows.Win32.System.Services.SERVICE_STATUS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def QueryServiceStatusEx(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, InfoLevel: win32more.Windows.Win32.System.Services.SC_STATUS_TYPE, lpBuffer: POINTER(Byte), cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def RegisterServiceCtrlHandlerA(lpServiceName: win32more.Windows.Win32.Foundation.PSTR, lpHandlerProc: win32more.Windows.Win32.System.Services.LPHANDLER_FUNCTION) -> win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE: ...
@winfunctype('ADVAPI32.dll')
def RegisterServiceCtrlHandlerW(lpServiceName: win32more.Windows.Win32.Foundation.PWSTR, lpHandlerProc: win32more.Windows.Win32.System.Services.LPHANDLER_FUNCTION) -> win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE: ...
RegisterServiceCtrlHandler = UnicodeAlias('RegisterServiceCtrlHandlerW')
@winfunctype('ADVAPI32.dll')
def RegisterServiceCtrlHandlerExA(lpServiceName: win32more.Windows.Win32.Foundation.PSTR, lpHandlerProc: win32more.Windows.Win32.System.Services.LPHANDLER_FUNCTION_EX, lpContext: VoidPtr) -> win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE: ...
@winfunctype('ADVAPI32.dll')
def RegisterServiceCtrlHandlerExW(lpServiceName: win32more.Windows.Win32.Foundation.PWSTR, lpHandlerProc: win32more.Windows.Win32.System.Services.LPHANDLER_FUNCTION_EX, lpContext: VoidPtr) -> win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE: ...
RegisterServiceCtrlHandlerEx = UnicodeAlias('RegisterServiceCtrlHandlerExW')
@winfunctype('ADVAPI32.dll')
def SetServiceObjectSecurity(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwSecurityInformation: win32more.Windows.Win32.Security.OBJECT_SECURITY_INFORMATION, lpSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def SetServiceStatus(hServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE, lpServiceStatus: POINTER(win32more.Windows.Win32.System.Services.SERVICE_STATUS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def StartServiceCtrlDispatcherA(lpServiceStartTable: POINTER(win32more.Windows.Win32.System.Services.SERVICE_TABLE_ENTRYA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def StartServiceCtrlDispatcherW(lpServiceStartTable: POINTER(win32more.Windows.Win32.System.Services.SERVICE_TABLE_ENTRYW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
StartServiceCtrlDispatcher = UnicodeAlias('StartServiceCtrlDispatcherW')
@winfunctype('ADVAPI32.dll')
def StartServiceA(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwNumServiceArgs: UInt32, lpServiceArgVectors: POINTER(win32more.Windows.Win32.Foundation.PSTR)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def StartServiceW(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwNumServiceArgs: UInt32, lpServiceArgVectors: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.BOOL: ...
StartService = UnicodeAlias('StartServiceW')
@winfunctype('ADVAPI32.dll')
def UnlockServiceDatabase(ScLock: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def NotifyServiceStatusChangeA(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwNotifyMask: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY, pNotifyBuffer: POINTER(win32more.Windows.Win32.System.Services.SERVICE_NOTIFY_2A)) -> UInt32: ...
@winfunctype('ADVAPI32.dll')
def NotifyServiceStatusChangeW(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwNotifyMask: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY, pNotifyBuffer: POINTER(win32more.Windows.Win32.System.Services.SERVICE_NOTIFY_2W)) -> UInt32: ...
NotifyServiceStatusChange = UnicodeAlias('NotifyServiceStatusChangeW')
@winfunctype('ADVAPI32.dll')
def ControlServiceExA(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwControl: UInt32, dwInfoLevel: UInt32, pControlParams: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ControlServiceExW(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwControl: UInt32, dwInfoLevel: UInt32, pControlParams: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
ControlServiceEx = UnicodeAlias('ControlServiceExW')
@winfunctype('ADVAPI32.dll')
def QueryServiceDynamicInformation(hServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE, dwInfoLevel: UInt32, ppDynamicInfo: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SecHost.dll')
def SubscribeServiceChangeNotifications(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, eEventType: win32more.Windows.Win32.System.Services.SC_EVENT_TYPE, pCallback: win32more.Windows.Win32.System.Services.PSC_NOTIFICATION_CALLBACK, pCallbackContext: VoidPtr, pSubscription: POINTER(win32more.Windows.Win32.System.Services.PSC_NOTIFICATION_REGISTRATION)) -> UInt32: ...
@winfunctype('SecHost.dll')
def UnsubscribeServiceChangeNotifications(pSubscription: win32more.Windows.Win32.System.Services.PSC_NOTIFICATION_REGISTRATION) -> Void: ...
@winfunctype('ADVAPI32.dll')
def WaitServiceState(hService: win32more.Windows.Win32.System.Services.SC_HANDLE, dwNotify: UInt32, dwTimeout: UInt32, hCancelEvent: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('api-ms-win-service-core-l1-1-3.dll')
def GetServiceRegistryStateKey(ServiceStatusHandle: win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE, StateType: win32more.Windows.Win32.System.Services.SERVICE_REGISTRY_STATE_TYPE, AccessMask: UInt32, ServiceStateKey: POINTER(win32more.Windows.Win32.System.Registry.HKEY)) -> UInt32: ...
@winfunctype('api-ms-win-service-core-l1-1-4.dll')
def GetServiceDirectory(hServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_HANDLE, eDirectoryType: win32more.Windows.Win32.System.Services.SERVICE_DIRECTORY_TYPE, lpPathBuffer: win32more.Windows.Win32.Foundation.PWSTR, cchPathBufferLength: UInt32, lpcchRequiredBufferLength: POINTER(UInt32)) -> UInt32: ...
@winfunctype('api-ms-win-service-core-l1-1-5.dll')
def GetSharedServiceRegistryStateKey(ServiceHandle: win32more.Windows.Win32.System.Services.SC_HANDLE, StateType: win32more.Windows.Win32.System.Services.SERVICE_SHARED_REGISTRY_STATE_TYPE, AccessMask: UInt32, ServiceStateKey: POINTER(win32more.Windows.Win32.System.Registry.HKEY)) -> UInt32: ...
@winfunctype('api-ms-win-service-core-l1-1-5.dll')
def GetSharedServiceDirectory(ServiceHandle: win32more.Windows.Win32.System.Services.SC_HANDLE, DirectoryType: win32more.Windows.Win32.System.Services.SERVICE_SHARED_DIRECTORY_TYPE, PathBuffer: win32more.Windows.Win32.Foundation.PWSTR, PathBufferLength: UInt32, RequiredBufferLength: POINTER(UInt32)) -> UInt32: ...
ENUM_SERVICE_STATE = UInt32
SERVICE_ACTIVE: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE = 1
SERVICE_INACTIVE: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE = 2
SERVICE_STATE_ALL: win32more.Windows.Win32.System.Services.ENUM_SERVICE_STATE = 3
class ENUM_SERVICE_STATUSA(Structure):
    lpServiceName: win32more.Windows.Win32.Foundation.PSTR
    lpDisplayName: win32more.Windows.Win32.Foundation.PSTR
    ServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS
class ENUM_SERVICE_STATUSW(Structure):
    lpServiceName: win32more.Windows.Win32.Foundation.PWSTR
    lpDisplayName: win32more.Windows.Win32.Foundation.PWSTR
    ServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS
ENUM_SERVICE_STATUS = UnicodeAlias('ENUM_SERVICE_STATUSW')
class ENUM_SERVICE_STATUS_PROCESSA(Structure):
    lpServiceName: win32more.Windows.Win32.Foundation.PSTR
    lpDisplayName: win32more.Windows.Win32.Foundation.PSTR
    ServiceStatusProcess: win32more.Windows.Win32.System.Services.SERVICE_STATUS_PROCESS
class ENUM_SERVICE_STATUS_PROCESSW(Structure):
    lpServiceName: win32more.Windows.Win32.Foundation.PWSTR
    lpDisplayName: win32more.Windows.Win32.Foundation.PWSTR
    ServiceStatusProcess: win32more.Windows.Win32.System.Services.SERVICE_STATUS_PROCESS
ENUM_SERVICE_STATUS_PROCESS = UnicodeAlias('ENUM_SERVICE_STATUS_PROCESSW')
ENUM_SERVICE_TYPE = UInt32
SERVICE_DRIVER: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 11
SERVICE_KERNEL_DRIVER: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 1
SERVICE_WIN32: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 48
SERVICE_WIN32_SHARE_PROCESS: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 32
SERVICE_ADAPTER: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 4
SERVICE_FILE_SYSTEM_DRIVER: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 2
SERVICE_RECOGNIZER_DRIVER: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 8
SERVICE_WIN32_OWN_PROCESS: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 16
SERVICE_USER_OWN_PROCESS: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 80
SERVICE_USER_SHARE_PROCESS: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE = 96
@winfunctype_pointer
def HANDLER_FUNCTION(dwControl: UInt32) -> Void: ...
@winfunctype_pointer
def HANDLER_FUNCTION_EX(dwControl: UInt32, dwEventType: UInt32, lpEventData: VoidPtr, lpContext: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def LPHANDLER_FUNCTION(dwControl: UInt32) -> Void: ...
@winfunctype_pointer
def LPHANDLER_FUNCTION_EX(dwControl: UInt32, dwEventType: UInt32, lpEventData: VoidPtr, lpContext: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def LPSERVICE_MAIN_FUNCTIONA(dwNumServicesArgs: UInt32, lpServiceArgVectors: POINTER(win32more.Windows.Win32.Foundation.PSTR)) -> Void: ...
@winfunctype_pointer
def LPSERVICE_MAIN_FUNCTIONW(dwNumServicesArgs: UInt32, lpServiceArgVectors: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> Void: ...
LPSERVICE_MAIN_FUNCTION = UnicodeAlias('LPSERVICE_MAIN_FUNCTIONW')
@winfunctype_pointer
def PFN_SC_NOTIFY_CALLBACK(pParameter: VoidPtr) -> Void: ...
@winfunctype_pointer
def PSC_NOTIFICATION_CALLBACK(dwNotify: UInt32, pCallbackContext: VoidPtr) -> Void: ...
PSC_NOTIFICATION_REGISTRATION = IntPtr
class QUERY_SERVICE_CONFIGA(Structure):
    dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE
    dwStartType: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE
    dwErrorControl: win32more.Windows.Win32.System.Services.SERVICE_ERROR
    lpBinaryPathName: win32more.Windows.Win32.Foundation.PSTR
    lpLoadOrderGroup: win32more.Windows.Win32.Foundation.PSTR
    dwTagId: UInt32
    lpDependencies: win32more.Windows.Win32.Foundation.PSTR
    lpServiceStartName: win32more.Windows.Win32.Foundation.PSTR
    lpDisplayName: win32more.Windows.Win32.Foundation.PSTR
class QUERY_SERVICE_CONFIGW(Structure):
    dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE
    dwStartType: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE
    dwErrorControl: win32more.Windows.Win32.System.Services.SERVICE_ERROR
    lpBinaryPathName: win32more.Windows.Win32.Foundation.PWSTR
    lpLoadOrderGroup: win32more.Windows.Win32.Foundation.PWSTR
    dwTagId: UInt32
    lpDependencies: win32more.Windows.Win32.Foundation.PWSTR
    lpServiceStartName: win32more.Windows.Win32.Foundation.PWSTR
    lpDisplayName: win32more.Windows.Win32.Foundation.PWSTR
QUERY_SERVICE_CONFIG = UnicodeAlias('QUERY_SERVICE_CONFIGW')
class QUERY_SERVICE_LOCK_STATUSA(Structure):
    fIsLocked: UInt32
    lpLockOwner: win32more.Windows.Win32.Foundation.PSTR
    dwLockDuration: UInt32
class QUERY_SERVICE_LOCK_STATUSW(Structure):
    fIsLocked: UInt32
    lpLockOwner: win32more.Windows.Win32.Foundation.PWSTR
    dwLockDuration: UInt32
QUERY_SERVICE_LOCK_STATUS = UnicodeAlias('QUERY_SERVICE_LOCK_STATUSW')
class SC_ACTION(Structure):
    Type: win32more.Windows.Win32.System.Services.SC_ACTION_TYPE
    Delay: UInt32
SC_ACTION_TYPE = Int32
SC_ACTION_NONE: win32more.Windows.Win32.System.Services.SC_ACTION_TYPE = 0
SC_ACTION_RESTART: win32more.Windows.Win32.System.Services.SC_ACTION_TYPE = 1
SC_ACTION_REBOOT: win32more.Windows.Win32.System.Services.SC_ACTION_TYPE = 2
SC_ACTION_RUN_COMMAND: win32more.Windows.Win32.System.Services.SC_ACTION_TYPE = 3
SC_ACTION_OWN_RESTART: win32more.Windows.Win32.System.Services.SC_ACTION_TYPE = 4
SC_ENUM_TYPE = Int32
SC_ENUM_PROCESS_INFO: win32more.Windows.Win32.System.Services.SC_ENUM_TYPE = 0
SC_EVENT_TYPE = Int32
SC_EVENT_DATABASE_CHANGE: win32more.Windows.Win32.System.Services.SC_EVENT_TYPE = 0
SC_EVENT_PROPERTY_CHANGE: win32more.Windows.Win32.System.Services.SC_EVENT_TYPE = 1
SC_EVENT_STATUS_CHANGE: win32more.Windows.Win32.System.Services.SC_EVENT_TYPE = 2
SC_HANDLE = VoidPtr
SC_STATUS_TYPE = Int32
SC_STATUS_PROCESS_INFO: win32more.Windows.Win32.System.Services.SC_STATUS_TYPE = 0
SERVICE_CONFIG = UInt32
SERVICE_CONFIG_DELAYED_AUTO_START_INFO: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 3
SERVICE_CONFIG_DESCRIPTION: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 1
SERVICE_CONFIG_FAILURE_ACTIONS: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 2
SERVICE_CONFIG_FAILURE_ACTIONS_FLAG: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 4
SERVICE_CONFIG_PREFERRED_NODE: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 9
SERVICE_CONFIG_PRESHUTDOWN_INFO: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 7
SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFO: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 6
SERVICE_CONFIG_SERVICE_SID_INFO: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 5
SERVICE_CONFIG_TRIGGER_INFO: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 8
SERVICE_CONFIG_LAUNCH_PROTECTED: win32more.Windows.Win32.System.Services.SERVICE_CONFIG = 12
class SERVICE_CONTROL_STATUS_REASON_PARAMSA(Structure):
    dwReason: UInt32
    pszComment: win32more.Windows.Win32.Foundation.PSTR
    ServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_PROCESS
class SERVICE_CONTROL_STATUS_REASON_PARAMSW(Structure):
    dwReason: UInt32
    pszComment: win32more.Windows.Win32.Foundation.PWSTR
    ServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_PROCESS
SERVICE_CONTROL_STATUS_REASON_PARAMS = UnicodeAlias('SERVICE_CONTROL_STATUS_REASON_PARAMSW')
class SERVICE_CUSTOM_SYSTEM_STATE_CHANGE_DATA_ITEM(Structure):
    u: _u_e__Union
    class _u_e__Union(Union):
        CustomStateId: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_CUSTOM_STATE_ID
        s: _s_e__Struct
        class _s_e__Struct(Structure):
            DataOffset: UInt32
            Data: Byte * 1
class SERVICE_DELAYED_AUTO_START_INFO(Structure):
    fDelayedAutostart: win32more.Windows.Win32.Foundation.BOOL
class SERVICE_DESCRIPTIONA(Structure):
    lpDescription: win32more.Windows.Win32.Foundation.PSTR
class SERVICE_DESCRIPTIONW(Structure):
    lpDescription: win32more.Windows.Win32.Foundation.PWSTR
SERVICE_DESCRIPTION = UnicodeAlias('SERVICE_DESCRIPTIONW')
SERVICE_DIRECTORY_TYPE = Int32
ServiceDirectoryPersistentState: win32more.Windows.Win32.System.Services.SERVICE_DIRECTORY_TYPE = 0
ServiceDirectoryTypeMax: win32more.Windows.Win32.System.Services.SERVICE_DIRECTORY_TYPE = 1
SERVICE_ERROR = UInt32
SERVICE_ERROR_CRITICAL: win32more.Windows.Win32.System.Services.SERVICE_ERROR = 3
SERVICE_ERROR_IGNORE: win32more.Windows.Win32.System.Services.SERVICE_ERROR = 0
SERVICE_ERROR_NORMAL: win32more.Windows.Win32.System.Services.SERVICE_ERROR = 1
SERVICE_ERROR_SEVERE: win32more.Windows.Win32.System.Services.SERVICE_ERROR = 2
class SERVICE_FAILURE_ACTIONSA(Structure):
    dwResetPeriod: UInt32
    lpRebootMsg: win32more.Windows.Win32.Foundation.PSTR
    lpCommand: win32more.Windows.Win32.Foundation.PSTR
    cActions: UInt32
    lpsaActions: POINTER(win32more.Windows.Win32.System.Services.SC_ACTION)
class SERVICE_FAILURE_ACTIONSW(Structure):
    dwResetPeriod: UInt32
    lpRebootMsg: win32more.Windows.Win32.Foundation.PWSTR
    lpCommand: win32more.Windows.Win32.Foundation.PWSTR
    cActions: UInt32
    lpsaActions: POINTER(win32more.Windows.Win32.System.Services.SC_ACTION)
SERVICE_FAILURE_ACTIONS = UnicodeAlias('SERVICE_FAILURE_ACTIONSW')
class SERVICE_FAILURE_ACTIONS_FLAG(Structure):
    fFailureActionsOnNonCrashFailures: win32more.Windows.Win32.Foundation.BOOL
class SERVICE_LAUNCH_PROTECTED_INFO(Structure):
    dwLaunchProtected: UInt32
@winfunctype_pointer
def SERVICE_MAIN_FUNCTIONA(dwNumServicesArgs: UInt32, lpServiceArgVectors: POINTER(POINTER(SByte))) -> Void: ...
@winfunctype_pointer
def SERVICE_MAIN_FUNCTIONW(dwNumServicesArgs: UInt32, lpServiceArgVectors: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> Void: ...
SERVICE_MAIN_FUNCTION = UnicodeAlias('SERVICE_MAIN_FUNCTIONW')
SERVICE_NOTIFY = UInt32
SERVICE_NOTIFY_CREATED: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 128
SERVICE_NOTIFY_CONTINUE_PENDING: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 16
SERVICE_NOTIFY_DELETE_PENDING: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 512
SERVICE_NOTIFY_DELETED: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 256
SERVICE_NOTIFY_PAUSE_PENDING: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 32
SERVICE_NOTIFY_PAUSED: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 64
SERVICE_NOTIFY_RUNNING: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 8
SERVICE_NOTIFY_START_PENDING: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 2
SERVICE_NOTIFY_STOP_PENDING: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 4
SERVICE_NOTIFY_STOPPED: win32more.Windows.Win32.System.Services.SERVICE_NOTIFY = 1
class SERVICE_NOTIFY_1(Structure):
    dwVersion: UInt32
    pfnNotifyCallback: win32more.Windows.Win32.System.Services.PFN_SC_NOTIFY_CALLBACK
    pContext: VoidPtr
    dwNotificationStatus: UInt32
    ServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_PROCESS
class SERVICE_NOTIFY_2A(Structure):
    dwVersion: UInt32
    pfnNotifyCallback: win32more.Windows.Win32.System.Services.PFN_SC_NOTIFY_CALLBACK
    pContext: VoidPtr
    dwNotificationStatus: UInt32
    ServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_PROCESS
    dwNotificationTriggered: UInt32
    pszServiceNames: win32more.Windows.Win32.Foundation.PSTR
class SERVICE_NOTIFY_2W(Structure):
    dwVersion: UInt32
    pfnNotifyCallback: win32more.Windows.Win32.System.Services.PFN_SC_NOTIFY_CALLBACK
    pContext: VoidPtr
    dwNotificationStatus: UInt32
    ServiceStatus: win32more.Windows.Win32.System.Services.SERVICE_STATUS_PROCESS
    dwNotificationTriggered: UInt32
    pszServiceNames: win32more.Windows.Win32.Foundation.PWSTR
SERVICE_NOTIFY_2 = UnicodeAlias('SERVICE_NOTIFY_2W')
class SERVICE_PREFERRED_NODE_INFO(Structure):
    usPreferredNode: UInt16
    fDelete: win32more.Windows.Win32.Foundation.BOOLEAN
class SERVICE_PRESHUTDOWN_INFO(Structure):
    dwPreshutdownTimeout: UInt32
SERVICE_REGISTRY_STATE_TYPE = Int32
ServiceRegistryStateParameters: win32more.Windows.Win32.System.Services.SERVICE_REGISTRY_STATE_TYPE = 0
ServiceRegistryStatePersistent: win32more.Windows.Win32.System.Services.SERVICE_REGISTRY_STATE_TYPE = 1
MaxServiceRegistryStateType: win32more.Windows.Win32.System.Services.SERVICE_REGISTRY_STATE_TYPE = 2
class SERVICE_REQUIRED_PRIVILEGES_INFOA(Structure):
    pmszRequiredPrivileges: win32more.Windows.Win32.Foundation.PSTR
class SERVICE_REQUIRED_PRIVILEGES_INFOW(Structure):
    pmszRequiredPrivileges: win32more.Windows.Win32.Foundation.PWSTR
SERVICE_REQUIRED_PRIVILEGES_INFO = UnicodeAlias('SERVICE_REQUIRED_PRIVILEGES_INFOW')
SERVICE_RUNS_IN_PROCESS = UInt32
SERVICE_RUNS_IN_NON_SYSTEM_OR_NOT_RUNNING: win32more.Windows.Win32.System.Services.SERVICE_RUNS_IN_PROCESS = 0
SERVICE_RUNS_IN_SYSTEM_PROCESS: win32more.Windows.Win32.System.Services.SERVICE_RUNS_IN_PROCESS = 1
SERVICE_SHARED_DIRECTORY_TYPE = Int32
ServiceSharedDirectoryPersistentState: win32more.Windows.Win32.System.Services.SERVICE_SHARED_DIRECTORY_TYPE = 0
SERVICE_SHARED_REGISTRY_STATE_TYPE = Int32
ServiceSharedRegistryPersistentState: win32more.Windows.Win32.System.Services.SERVICE_SHARED_REGISTRY_STATE_TYPE = 0
class SERVICE_SID_INFO(Structure):
    dwServiceSidType: UInt32
class SERVICE_START_REASON(Structure):
    dwReason: UInt32
SERVICE_START_TYPE = UInt32
SERVICE_AUTO_START: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE = 2
SERVICE_BOOT_START: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE = 0
SERVICE_DEMAND_START: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE = 3
SERVICE_DISABLED: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE = 4
SERVICE_SYSTEM_START: win32more.Windows.Win32.System.Services.SERVICE_START_TYPE = 1
class SERVICE_STATUS(Structure):
    dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE
    dwCurrentState: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE
    dwControlsAccepted: UInt32
    dwWin32ExitCode: UInt32
    dwServiceSpecificExitCode: UInt32
    dwCheckPoint: UInt32
    dwWaitHint: UInt32
SERVICE_STATUS_CURRENT_STATE = UInt32
SERVICE_CONTINUE_PENDING: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE = 5
SERVICE_PAUSE_PENDING: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE = 6
SERVICE_PAUSED: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE = 7
SERVICE_RUNNING: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE = 4
SERVICE_START_PENDING: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE = 2
SERVICE_STOP_PENDING: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE = 3
SERVICE_STOPPED: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE = 1
SERVICE_STATUS_HANDLE = VoidPtr
class SERVICE_STATUS_PROCESS(Structure):
    dwServiceType: win32more.Windows.Win32.System.Services.ENUM_SERVICE_TYPE
    dwCurrentState: win32more.Windows.Win32.System.Services.SERVICE_STATUS_CURRENT_STATE
    dwControlsAccepted: UInt32
    dwWin32ExitCode: UInt32
    dwServiceSpecificExitCode: UInt32
    dwCheckPoint: UInt32
    dwWaitHint: UInt32
    dwProcessId: UInt32
    dwServiceFlags: win32more.Windows.Win32.System.Services.SERVICE_RUNS_IN_PROCESS
class SERVICE_TABLE_ENTRYA(Structure):
    lpServiceName: win32more.Windows.Win32.Foundation.PSTR
    lpServiceProc: win32more.Windows.Win32.System.Services.LPSERVICE_MAIN_FUNCTIONA
class SERVICE_TABLE_ENTRYW(Structure):
    lpServiceName: win32more.Windows.Win32.Foundation.PWSTR
    lpServiceProc: win32more.Windows.Win32.System.Services.LPSERVICE_MAIN_FUNCTIONW
SERVICE_TABLE_ENTRY = UnicodeAlias('SERVICE_TABLE_ENTRYW')
class SERVICE_TIMECHANGE_INFO(Structure):
    liNewTime: Int64
    liOldTime: Int64
class SERVICE_TRIGGER(Structure):
    dwTriggerType: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_TYPE
    dwAction: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_ACTION
    pTriggerSubtype: POINTER(Guid)
    cDataItems: UInt32
    pDataItems: POINTER(win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_SPECIFIC_DATA_ITEM)
SERVICE_TRIGGER_ACTION = UInt32
SERVICE_TRIGGER_ACTION_SERVICE_START: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_ACTION = 1
SERVICE_TRIGGER_ACTION_SERVICE_STOP: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_ACTION = 2
class SERVICE_TRIGGER_CUSTOM_STATE_ID(Structure):
    Data: UInt32 * 2
class SERVICE_TRIGGER_INFO(Structure):
    cTriggers: UInt32
    pTriggers: POINTER(win32more.Windows.Win32.System.Services.SERVICE_TRIGGER)
    pReserved: POINTER(Byte)
class SERVICE_TRIGGER_SPECIFIC_DATA_ITEM(Structure):
    dwDataType: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_SPECIFIC_DATA_ITEM_DATA_TYPE
    cbData: UInt32
    pData: POINTER(Byte)
SERVICE_TRIGGER_SPECIFIC_DATA_ITEM_DATA_TYPE = UInt32
SERVICE_TRIGGER_DATA_TYPE_BINARY: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_SPECIFIC_DATA_ITEM_DATA_TYPE = 1
SERVICE_TRIGGER_DATA_TYPE_STRING: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_SPECIFIC_DATA_ITEM_DATA_TYPE = 2
SERVICE_TRIGGER_DATA_TYPE_LEVEL: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_SPECIFIC_DATA_ITEM_DATA_TYPE = 3
SERVICE_TRIGGER_DATA_TYPE_KEYWORD_ANY: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_SPECIFIC_DATA_ITEM_DATA_TYPE = 4
SERVICE_TRIGGER_DATA_TYPE_KEYWORD_ALL: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_SPECIFIC_DATA_ITEM_DATA_TYPE = 5
SERVICE_TRIGGER_TYPE = UInt32
SERVICE_TRIGGER_TYPE_CUSTOM: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_TYPE = 20
SERVICE_TRIGGER_TYPE_DEVICE_INTERFACE_ARRIVAL: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_TYPE = 1
SERVICE_TRIGGER_TYPE_DOMAIN_JOIN: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_TYPE = 3
SERVICE_TRIGGER_TYPE_FIREWALL_PORT_EVENT: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_TYPE = 4
SERVICE_TRIGGER_TYPE_GROUP_POLICY: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_TYPE = 5
SERVICE_TRIGGER_TYPE_IP_ADDRESS_AVAILABILITY: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_TYPE = 2
SERVICE_TRIGGER_TYPE_NETWORK_ENDPOINT: win32more.Windows.Win32.System.Services.SERVICE_TRIGGER_TYPE = 6


make_ready(__name__)
